==> tecfy_corev2_package-1.1.106.tar.gz: lib/models/entity/report_property.model.dart <==
part of tecfy_corev2_client_package;

class ReportProperty {
  late String dbName;
  late ValueTypes type;

  late String nameAr;
  late String nameEn;
  String? format;
  late bool sortable;
  int sortId = 0;

  String? colorField;
  String? color;
  String? prefixField;
  String? suffixField;
  String? prefix;
  String? suffix;

  String? drillDownEntity;
  String? drillDownIdField;
  bool drillDownEntityDynamic = false;

  String? descriptionAr;
  String? descriptionEn;

  /// get the name according to login language
  String? get description => LocalConfigService.isArabic
      ? (descriptionAr ?? descriptionEn)
      : (descriptionEn ?? descriptionAr);

  /// get the name according to login language
  String get name => LocalConfigService.isArabic ? nameAr : nameEn;

  ReportProperty(
      {this.dbName = '',
      this.nameEn = '',
      this.type = ValueTypes.Number,
      this.nameAr = ''});

  ReportProperty.fromMap(Map<String, dynamic> row) {
    dbName = lowerFirst(row['dbName']) ?? '';
    type = ValueTypes.values[row['type']];
    nameAr = row['nameAr'] ?? row['name']?['ar'] ?? dbName;
    nameEn = row['nameEn'] ?? row['name']?['en'] ?? dbName;
    descriptionAr = row['descriptionAr'];
    descriptionEn = row['descriptionEn'];
    drillDownEntity = lowerFirst(row['drillDownEntity']);
    drillDownIdField = lowerFirst(row['drillDownIdField']);
    drillDownEntityDynamic = row['drillDownEntityDynamic'] ?? false;
    format = row['format'];
    if (format?.isEmpty ?? false) format = null;
    sortable = row['sortable'] ?? false;
    sortId = row['sortId'] ?? 0;
    colorField = lowerFirst(row['colorField']);
    color = row['color'];
    prefixField = row['prefixField'];
    suffixField = row['suffixField'];
    prefix = row['prefix'];
    suffix = row['suffix'];
  }

  String? lowerFirst(String? s) {
    if (s == null || s.isEmpty) return '';
    return '${s[0].toLowerCase()}${s.substring(1)}';
  }

  String? upperFirst(String? s) {
    if (s == null || s.isEmpty) return '';
    return '${s[0].toUpperCase()}${s.substring(1)}';
  }
}

==> tecfy_corev2_package-1.1.117.tar.gz: lib/models/entity/report_property.model.dart <==
part of tecfy_corev2_client_package;

class ReportProperty {
  late String dbName;
  late ValueTypes type;
  PropertyTypes? propertyType;

  late String nameAr;
  late String nameEn;
  String? format;
  late bool sortable;
  int sortId = 0;

  String? colorField;
  String? color;
  String? prefixField;
  String? suffixField;
  String? prefix;
  String? suffix;

  String? drillDownEntity;
  String? drillDownIdField;
  bool drillDownEntityDynamic = false;

  String? descriptionAr;
  String? descriptionEn;

  /// get the name according to login language
  String? get description => LocalConfigService.isArabic
      ? (descriptionAr ?? descriptionEn)
      : (descriptionEn ?? descriptionAr);

  /// get the name according to login language
  String get name => LocalConfigService.isArabic ? nameAr : nameEn;

  ReportProperty(
      {this.dbName = '',
      this.nameEn = '',
      this.type = ValueTypes.Number,
      this.nameAr = ''});

  ReportProperty.fromMap(Map<String, dynamic> row) {
    dbName = lowerFirst(row['dbName']) ?? '';
    type = ValueTypes.values[row['type'] ?? 0];
    if (row.containsKey('propertyType') && (row['propertyType'] != null))
      propertyType = PropertyTypes.values.firstWhere(
          (element) => element.name.toString() == row['propertyType']);
    nameAr = row['nameAr'] ?? row['name']?['ar'] ?? dbName;
    nameEn = row['nameEn'] ?? row['name']?['en'] ?? dbName;
    descriptionAr = row['descriptionAr'];
    descriptionEn = row['descriptionEn'];
    drillDownEntity = lowerFirst(row['drillDownEntity']);
    drillDownIdField = lowerFirst(row['drillDownIdField']);
    drillDownEntityDynamic = row['drillDownEntityDynamic'] ?? false;
    format = row['format'];
    if (format?.isEmpty ?? false) format = null;
    sortable = row['sortable'] ?? false;
    sortId = row['sortId'] ?? 0;
    colorField = lowerFirst(row['colorField']);
    color = row['color'];
    prefixField = row['prefixField'];
    suffixField = row['suffixField'];
    prefix = row['prefix'];
    suffix = row['suffix'];
  }

  String? lowerFirst(String? s) {
    if (s == null || s.isEmpty) return '';
    return '${s[0].toLowerCase()}${s.substring(1)}';
  }

  String? upperFirst(String? s) {
    if (s == null || s.isEmpty) return '';
    return '${s[0].toUpperCase()}${s.substring(1)}';
  }
}
